EXSWCPHIPT-42 - Add HIP RTC support to the test framework (#2719)

* EXSWCPHIPT-42 - Add HIP RTC support to the test framework
* Removed ifdef from hipTestContext class

[ROCm/hip commit: 604de0f817]
Cette révision appartient à :
Fábio
2022-06-13 11:05:02 +01:00
révisé par GitHub
Parent 572a6ea4bc
révision bdee650e17
14 fichiers modifiés avec 569 ajouts et 42 suppressions
+6
Voir le fichier
@@ -0,0 +1,6 @@
#include <kernels.hh>
__global__ void Set(int* Ad, int val) {
int tx = threadIdx.x + blockIdx.x * blockDim.x;
Ad[tx] = val;
}